%############################################################################
%#
%#                          function mandhala_mat
%#
%#    adds properties of common magnetic materials to ring-structure.
%#    
%#   input: 
%#     ring = structure as produced by mandhala_2D
%#     type = magnetic material
%#    
%#   output:
%#     ring = rotated structure
%#     ring.Br  = remanence [T]
%#     ring.Hc  = Coercivity [A/m]
%#     ring.mu  = permittivity
%#     ring.sig = el. conductivity [MS/m]
%#
%#      (c) P. Blmler 3/07
%############################################################################
%----------------------------------------------------------------------------
%  version 1.0 PB 26/3/07    (please change this when code is altered)
%----------------------------------------------------------------------------

function ring=mandhala_rot(ring,type)

switch type
    case 'Air'
        ring.mat='Air';
        ring.Br=0;
        ring.Hc=0;
        ring.mu=1;
        ring.sig=0;
    case 'NdFeB31'  %NdFeB BHmax=31
        ring.mat='NdFeB31';
        ring.Br=11.2;
        ring.Hc=875378;
        ring.mu=1.045;
        ring.sig=0.694;
    case 'NdFeB35'  %NdFeB BHmax=35
        ring.mat='NdFeB35';
        ring.Br=12.3;
        ring.Hc=947000;
        ring.mu=1.045;
        ring.sig=0.694;
    case 'NdFeB38'  %NdFeB BHmax=38
        ring.mat='NdFeB38';
        ring.Br=12.5;
        ring.Hc=962916;
        ring.mu=1.048;
        ring.sig=0.667;
    case 'NdFeB40'  %NdFeB BHmax=40
        ring.mat='NdFeB40';
        ring.Br=12.6;
        ring.Hc=978832;
        ring.mu=1.049;
        ring.sig=0.667;
    case 'NdFeB44'  %NdFeB BHmax=44
        ring.mat='NdFeB44';
        ring.Br=13.5;
        ring.Hc=875378;
        ring.mu=1.045;
        ring.sig=0.694;    
    case 'NdFeB45'  %NdFeB BHmax=45
        ring.mat='NdFeB45';
        ring.Br=13.55;
        ring.Hc=875000;
        ring.mu=1.045;
        ring.sig=0.694;    
    case 'NdFeB48'  %NdFeB BHmax=48
        ring.mat='NdFeB48';
        ring.Br=13.55;
        ring.Hc=875000;
        ring.mu=1.045;
        ring.sig=0.694;    
    case 'NdFeB53'  %NdFeB BHmax=53
        ring.mat='NdFeB53';
        ring.Br=14.33;
        ring.Hc=875000;
        ring.mu=1.045;
        ring.sig=0.694;    
    case 'SmCo20'  %SmCo5 BHmax=20
        ring.mat='SmCo20';
        ring.Br=9.1;
        ring.Hc=693000;
        ring.mu=1.0345;
        ring.sig=1.176;
    case 'SmCo24'  %SmCo5 BHmax=24
        ring.mat='SmCo24';
        ring.Br=10;
        ring.Hc=724000;
        ring.mu=1.11;
        ring.sig=1.176;
    case 'SmCo27'  %SmCo5 BHmax=27
        ring.mat='SmCo27';
        ring.Br=10.7;
        ring.Hc=772000;
        ring.mu=1.103;
        ring.sig=1.176;
    case 'Sm2Co26' %Sm2Co17 BHmax=26 (Dexter)
        ring.mat='Sm2Co26';
        ring.Br=10.5;
        ring.Hc=716218;
        ring.mu=1.1;
        ring.sig=1.176;
    case 'Sm2Co28'   %Sm2Co17 BHmax=28 (Dexter)
        ring.mat='Sm2Co28';
        ring.Br=10.9;
        ring.Hc=517268;
        ring.mu=1.1;
        ring.sig=1.176;
end
        