%############################################################################
%#
%#                          function mandhala_write_FEMM
%#
%#    creates FEMM geometry file.
%#    
%#   input: 
%#     ring = structure as produced by mandhala_2D
%#     file = output filename
%#     dist = [distance inner circle, distance outer box] (optional, default=[0.75*inner radius, outer_radius*1.3]);
%#     mesh = precision of mesh width (optional)
%#     prec = presision (optional, default = 1e-8)
%# comments = comment string (optional)
%#
%#      (c) P. Blmler 3/07
%############################################################################
%----------------------------------------------------------------------------
%  version 1.0 PB 26/3/07    (please change this when code is altered)
%----------------------------------------------------------------------------

function mandhala_write_FEMM(ring,filename,dist,mesh,prec,comments)

RN=length(ring);
switch nargin 
    case 2
      dist=[0.75*ring{1}.r(1),1.3*ring{RN}.r(3)];  
      mesh=[5e-3,3e-2,1e-1]*ring{RN}.r(3);
      prec=1e-8;
      comments='';
    case 3
      mesh=[1e-3,1e-2,1e-1]*ring{RN}.r(3);
      prec=1e-8;
      comments='';
    case 4
      prec=1e-8;
      comments='';
    case 5
      comments='';
end

fid=fopen(filename,'w');

%GENERAL HEADER
fprintf(fid,'[Format]      =  3.0\n');
fprintf(fid,'[Frequency]   =  0\n');
fprintf(fid,['[Precision]   =  ',num2str(prec),'\n']);
fprintf(fid,'[Depth]       =  1\n');
fprintf(fid,'[LengthUnits] =  millimeters\n');
fprintf(fid,'[ProblemType] =  planar\n');
fprintf(fid,'[Coordinates] =  cartesian\n');
fprintf(fid,['[Comment]     =  ',comments,'\n']);

%POINT PROPERTIES 
fprintf(fid,'[PointProps]   = 0\n');

%BOUNDARY PROPERTIES (only outer box = 0)
fprintf(fid,'[BdryProps]   = 1\n');
fprintf(fid,'  <BeginBdry>\n');
fprintf(fid,'    <BdryName> = "zero"\n');
fprintf(fid,'    <BdryType> = 0\n');
fprintf(fid,'    <A_0> = 0\n');
fprintf(fid,'    <A_1> = 0\n');
fprintf(fid,'    <A_2> = 0\n');
fprintf(fid,'    <Phi> = 0\n');
fprintf(fid,'    <c0> = 0\n');
fprintf(fid,'    <c1> = 0\n');
fprintf(fid,'    <Mu_ssd> = 0\n');
fprintf(fid,'    <Sigma_ssd> = 0\n');
fprintf(fid,'  <EndBdry>\n');

%BLOCK PROPERTIES (rings + Air)
%Air
fprintf(fid,['[BlockProps]  = ',num2str(RN+1),'\n']);
fprintf(fid,'  <BeginBlock>\n');
fprintf(fid,'    <BlockName> = "Air"\n');
fprintf(fid,'    <Mu_x> = 1\n');
fprintf(fid,'    <Mu_y> = 1\n');
fprintf(fid,'    <H_c> = 0\n');
fprintf(fid,'    <H_cAngle> = 0\n');
fprintf(fid,'    <J_re> = 0\n');
fprintf(fid,'    <J_im> = 0\n');
fprintf(fid,'    <Sigma> = 0\n');
fprintf(fid,'    <d_lam> = 0\n');
fprintf(fid,'    <Phi_h> = 0\n');
fprintf(fid,'    <Phi_hx> = 0\n');
fprintf(fid,'    <Phi_hy> = 0\n');
fprintf(fid,'    <LamType> = 0\n');
fprintf(fid,'    <LamFill> = 1\n');
fprintf(fid,'    <BHPoints> = 0\n');
fprintf(fid,'  <EndBlock>\n');
%Magnets
for i=1:RN
   fprintf(fid,'  <BeginBlock>\n');
   fprintf(fid,['    <BlockName> = "M',num2str(i),'"\n']);
   fprintf(fid,['    <Mu_x> = ',num2str(ring{i}.mu),'\n']);
   fprintf(fid,['    <Mu_y> = ',num2str(ring{i}.mu),'\n']);
   fprintf(fid,['    <H_c> = ',num2str(ring{i}.Hc),'\n']);
   fprintf(fid,'    <H_cAngle> = 0\n');
   fprintf(fid,'    <J_re> = 0\n');
   fprintf(fid,'    <J_im> = 0\n');
   fprintf(fid,['    <Sigma> = ',num2str(ring{i}.sig),'\n']);
   fprintf(fid,'    <d_lam> = 0\n');
   fprintf(fid,'    <Phi_h> = 0\n');
   fprintf(fid,'    <Phi_hx> = 0\n');
   fprintf(fid,'    <Phi_hy> = 0\n');
   fprintf(fid,'    <LamType> = 0\n');
   fprintf(fid,'    <LamFill> = 1\n');
   fprintf(fid,'    <BHPoints> = 0\n');
   fprintf(fid,'  <EndBlock>\n');
end

%CIRCUIT = points PROPERTIES
fprintf(fid,'[CircuitProps]  = 0\n');
num_points=0;
for i=1:RN
  num_points=num_points+ring{i}.N*ring{i}.n;
end
fprintf(fid,['[NumPoints] = ',num2str(num_points+6),'\n']);

for i=1:RN
  for j=1:ring{i}.N
    for k=1:ring{i}.n
     fprintf(fid,[num2str(ring{i}.p(j,k,1)),'\t',num2str(ring{i}.p(j,k,2)),'\t1\t0\t0\n']);
    end
  end
end
fprintf(fid,[num2str(dist(2)),'\t',num2str(dist(2)),'\t',num2str(mesh(3)),'\t1\t0\t0\n']);
fprintf(fid,[num2str(dist(2)),'\t',num2str(-dist(2)),'\t',num2str(mesh(3)),'\t1\t0\t0\n']);
fprintf(fid,[num2str(-dist(2)),'\t',num2str(-dist(2)),'\t',num2str(mesh(3)),'\t1\t0\t0\n']);
fprintf(fid,[num2str(-dist(2)),'\t',num2str(dist(2)),'\t',num2str(mesh(3)),'\t1\t0\t0\n']);
fprintf(fid,[num2str(-dist(1)),'\t0\t',num2str(mesh(1)),'\t1\t0\t0\n']);
fprintf(fid,[num2str(dist(1)),'\t0\t',num2str(mesh(1)),'\t1\t0\t0\n']);

%SEGEMENT = line bewteen points (as defined by index from before)
fprintf(fid,['[NumSegments] = ',num2str(num_points+4),'\n']);
index=0;
for i=1:RN
  for j=1:ring{i}.N
    i0=index;
    for k=1:ring{i}.n-1
        fprintf(fid,[num2str(index),'\t',num2str(index+1),'\t',num2str(mesh(2)),'\t0\t0\t0\n']);
        index=index+1;
    end
    fprintf(fid,[num2str(index),'\t',num2str(i0),'\t',num2str(mesh(2)),'\t0\t0\t0\n']);
    index=index+1;
  end
end
fprintf(fid,[num2str(index),'\t',num2str(index+1),'\t',num2str(mesh(3)),'\t0\t0\t0\n']);
fprintf(fid,[num2str(index+1),'\t',num2str(index+2),'\t',num2str(mesh(3)),'\t0\t0\t0\n']);
fprintf(fid,[num2str(index+2),'\t',num2str(index+3),'\t',num2str(mesh(3)),'\t0\t0\t0\n']);
fprintf(fid,[num2str(index+3),'\t',num2str(index),'\t',num2str(mesh(3)),'\t0\t0\t0\n']);

%ARCS 
fprintf(fid,'[NumArcSegments] = 2\n');
last=index+4;
fprintf(fid,[num2str(last),'\t',num2str(last+1),'\t180\t10\t0\t0\t0\n']);
fprintf(fid,[num2str(last+1),'\t',num2str(last),'\t180\t10\t0\t0\t0\n']);
fprintf(fid,'[NumHoles] = 0\n');

%BLOCK PROPERTIES 
num_blocks=0;
for i=1:RN
  num_blocks=num_blocks+ring{i}.N;
end

fprintf(fid,['[NumBlockLabels] = ',num2str(num_blocks+3),'\n']);
for i=1:RN
  for j=1:ring{i}.N
     m_angle=mod(ring{i}.m(j)*180/pi,360);
     fprintf(fid,[num2str(ring{i}.c(j,1)),'\t',num2str(ring{i}.c(j,2)),'\t2\t',num2str(mesh(2)),'\t0\t',num2str(m_angle),'\t0\n']);
  end
end
fprintf(fid,['0\t',num2str(1.05*dist(1)),'\t1\t',num2str(mesh(2)),'\t0\t0\t0\n']);
fprintf(fid,['0\t0\t1\t',num2str(mesh(1)),'\t0\t0\t0\n']);
fprintf(fid,[num2str(0.95*dist(2)),'\t',num2str(0.95*dist(2)),'\t1\t',num2str(mesh(3)),'\t0\t0\t0\n']);

fclose(fid);



